local_function_collections library

Classes

BuildContext
A handle to the location of a widget in the widget tree.
CancelToken
Controls cancellation of Dio's requests.
File
A reference to a file on the file system.
FlutterSecureStorage
A class to manage secure storage in a Flutter application across multiple platforms.
LocalAPIsRequest
LocalDialogFunction
LocalRouteNavigator
LocalSecureStorage
Response<T>
The Response class contains the payload (could be transformed) that respond from the request, and other information of the response.
UploadFile
Widget
Describes the configuration for an Element.

Enums

RequestType
TextAlign
Whether and how to align text horizontally.

Typedefs

HttpErrorHandler = void Function(DioException exception, StackTrace stackTrace)

Exceptions / Errors

DioException
DioException describes the exception info when a request failed.