LocalSecureStorage class

Constructors

LocalSecureStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearKey() Future<bool>
Clear Key
deleteKey({required String key}) Future<bool>
Delete Key
readKey({required String key}) Future<String?>
Read Key
writeKey({required String key, String? data}) Future<bool>
Write Key